#old_version_warning {
  text-align:  center;
  padding:     0.1em;
  margin:      0;
  font-size:   1.4em;
}

body.with-js #old_version_warning {
  display:          none;
  text-align:       left;
  position:         fixed;
  top:              20%;
  left:	            30%;
  width:            40%;
  background-color: #fff;
  border:           1px solid #000;
  padding:          1em;
  z-index:          10000;
}

#old_version_warning span.closebar {
  float:            right;
  position:         relative;
  right:            -0.5em;
  top:              -0.5em;
}

#old_version_warning span.closebar a {
  text-decoration:  none;
}

body.no-js #old_version_warning span.closebar {
  display: none;
}

.previous_page, .next_page, .toc_page {
  font-size:      1.2em;
}

.previous_page {
  float:        left;
  clear:        left;
}

.next_page {
  float:        right;
  clear:        right;
}

.toc_page {
  position:     absolute;
  width:	10em;
  left:         45%;
}

#chapter {
  line-height: 1.5;
}

#chapter table {
  margin-top:       1em;
  margin-bottom:    1em;
}

#chapter table td {
  padding-left:     1em;
  padding-right:    1em;
  background-color: #eaeaea;
  border: thin solid white;
  font-size: 80%;
}

td .docbook_option, td .docbook_emphasis {
  font-size: 125%;
}

/* Index section styling */

h3.index {
  padding-top: 10px;
  border-bottom: medium solid #000;
  margin-bottom: 10px;
}

dl dt
{
  clear: left;
  float: left;
  margin: 0;
  font-weight: bold;
  padding-left: 2em;
  line-height: 1.1;
}

dl dd
{
  margin-left: 4em;
  padding-top: 0.2em;
  clear: left;
  line-height: 1.1;
  white-space: normal;
}

dl dd dl
{
  margin-left: -2em;
}


/* Side Table of Contents */

 #outer > #toc {
   position:     fixed;
   top:        35%;
   left:       0;
   z-index:      3000;
 }

 #outer > #toc img {
   position:     fixed;
   top:        35%;
   left:       0;
   background-color:   #304b66;
   padding:      0.5em;
   z-index:      3000;
   display:      none;
 }

 #outer > #toc img:hover {
   cursor:       pointer;
   background-color:   #000;
 }

 #outer > #toc > ul {
   position:     fixed;
   top:        30%;
   background-color:   #fff;
   min-height:     200px;
   max-height:     65%;
   overflow-y:     auto;
   padding:      0.5em 0;
   border-top:     1px solid #bbb;
   border-bottom:      1px solid #bbb;
   z-index:      3000;
 }
 #outer > #toc a {
   font-size:      1.2em;
   color:        #304b67;
   text-decoration:    none;
   padding:      0 0.5em;
 }
 #outer > #toc a:hover {
   color:        #000;
 }

 @media all and ( max-width: 640px ){
   #outer > #toc {
     display:    none;
   }
 }

/* Changebars  -- experimental */
.changed {
  border-right: 5px solid #000;
}
