#inner img:not(.sponsor_logo) {
	float:				left;
	margin:				0 1em 0.5em 0;
}

#book_info {
	min-height:			100px;
}

ul#sponsor_list {
	list-style: none;
	overflow: hidden;
	padding-left: 0;
}

img.sponsor_logo {
	vertical-align:			top;
	margin:				0 1em 0 0;
}
